#include <iostream>
#include <fstream>

using namespace std;

Double_t breit_wigner(Double_t *x,Double_t *par){
  return par[0]*par[2]/(2*TMath::Pi()*((x[0]-par[1])*(x[0]-par[1])+par[2]*par[2]/4));
}

void width(){

	TH1D* histo = new TH1D("histo","",100,124.95,125.05);

	char* inputFile = (char*)"mass.out";
        ifstream inFile(inputFile,ios::in);

        if(!inFile){
          cout << " Cannot open file " << inputFile << endl;
          exit(0);
        }

	double mass;
	inFile >> mass;
        while(!inFile.eof()){

		inFile >> mass;
		cout << mass << endl;
		histo->Fill(mass);
        }

	// Plotting
        TCanvas* canvas = new TCanvas("canvas","",700,400);
        canvas->SetFillColor(0);

	histo->SetStats(0);
	histo->SetFillColor(5);
	histo->GetXaxis()->SetTitle("m_{H} (GeV)");
	histo->GetYaxis()->SetTitle("Arbitrary units");
	histo->Draw();

        Double_t fitRangeMin = 124.9,
                 fitRangeMax = 125.1;
        const int nPar = 3; // number of parameters in the fit


        TF1* theFit = new TF1("theFit",breit_wigner,fitRangeMin,fitRangeMax,nPar);

        theFit->SetParameter(1,125);
        theFit->SetParameter(0,0.01);

	histo->Fit("theFit","R0");
	theFit->DrawClone("same");
	canvas->Print("width.pdf");

	cout << endl << "Width from the fit = " << theFit->GetParameter(2) << endl;
	exit(0);
}
